package sun.awt.windows;

import sun.awt.SunToolkit;
import java.awt.event.AdjustmentEvent;
import java.awt.Scrollbar;
import java.awt.Dimension;
import java.awt.peer.ScrollbarPeer;

final class WScrollbarPeer extends WComponentPeer implements ScrollbarPeer
{
    private boolean dragInProgress;
    
    static native int getScrollbarSize(int p0);
    
    @Override
    public Dimension getMinimumSize() {
        if (((Scrollbar)this.target).getOrientation() == 1) {
            return new Dimension(getScrollbarSize(1), 50);
        }
        return new Dimension(50, getScrollbarSize(0));
    }
    
    @Override
    public native void setValues(int p0, int p1, int p2, int p3);
    
    @Override
    public native void setLineIncrement(int p0);
    
    @Override
    public native void setPageIncrement(int p0);
    
    WScrollbarPeer(Scrollbar scrollbar) {
        super(scrollbar);
        this.dragInProgress = false;
    }
    
    @Override
    native void create(WComponentPeer p0);
    
    @Override
    void initialize() {
        Scrollbar scrollbar = (Scrollbar)this.target;
        this.setValues(scrollbar.getValue(), scrollbar.getVisibleAmount(), scrollbar.getMinimum(), scrollbar.getMaximum());
        super.initialize();
    }
    
    private void postAdjustmentEvent(final int n, final int n2, final boolean b) {
        final Scrollbar target = (Scrollbar)this.target;
        SunToolkit.executeOnEventHandlerThread(target, new Runnable() {
            @Override
            public void run() {
                target.setValueIsAdjusting(b);
                target.setValue(n2);
                WScrollbarPeer.this.postEvent(new AdjustmentEvent(target, 601, n, n2, b));
            }
        });
    }
    
    void lineUp(int n) {
        this.postAdjustmentEvent(2, n, false);
    }
    
    void lineDown(int n) {
        this.postAdjustmentEvent(1, n, false);
    }
    
    void pageUp(int n) {
        this.postAdjustmentEvent(3, n, false);
    }
    
    void pageDown(int n) {
        this.postAdjustmentEvent(4, n, false);
    }
    
    void warp(int n) {
        this.postAdjustmentEvent(5, n, false);
    }
    
    void drag(int n) {
        if (!this.dragInProgress) {
            this.dragInProgress = true;
        }
        this.postAdjustmentEvent(5, n, true);
    }
    
    void dragEnd(final int n) {
        final Scrollbar target = (Scrollbar)this.target;
        if (!this.dragInProgress) {
            return;
        }
        this.dragInProgress = false;
        SunToolkit.executeOnEventHandlerThread(target, new Runnable() {
            @Override
            public void run() {
                target.setValueIsAdjusting(false);
                WScrollbarPeer.this.postEvent(new AdjustmentEvent(target, 601, 5, n, false));
            }
        });
        return;
    }
    
    @Override
    public boolean shouldClearRectBeforePaint() {
        return false;
    }
}
